@@ -9,6 +9,7 @@ from src.peeringdb import pdb
 from src.ip import ip
 from src.shodan import shodan
 from src.whois import whois
+from src.api import api
 
 class Throne:
     def __init__(self):
@@ -32,4 +33,5 @@ cli.add_command(bgp)
 cli.add_command(pdb)
 cli.add_command(ip)
 cli.add_command(shodan)
-cli.add_command(whois)
\ No newline at end of file
+cli.add_command(whois)
+cli.add_command(api)
\ No newline at end of file
